Method: RubyProf.measure_mode

Defined in:
ext/ruby_prof.c

.measure_modeObject

Returns what ruby-prof is measuring. Valid values include:

RubyProf::PROCESS_TIME - Measure process time. This is default. It is implemented using the clock functions in the C Runtime library. RubyProf::WALL_TIME - Measure wall time using gettimeofday on Linx and GetLocalTime on Windows RubyProf::CPU_TIME - Measure time using the CPU clock counter. This mode is only supported on Pentium or PowerPC platforms. RubyProf::ALLOCATIONS - Measure object allocations. This requires a patched Ruby interpreter. RubyProf::MEMORY - Measure memory size. This requires a patched Ruby interpreter. RubyProf::GC_RUNS - Measure number of garbage collections. This requires a patched Ruby interpreter. RubyProf::GC_TIME - Measure time spent doing garbage collection. This requires a patched Ruby interpreter.



1288
1289
1290
1291
1292
# File 'ext/ruby_prof.c', line 1288

static VALUE
prof_get_measure_mode(VALUE self)
{
    return INT2NUM(measure_mode);
}